package tree

import (
	"encoding/hex"
	"math/big"
	"testing"

	"github.com/ethereum/go-ethereum/common"
	"github.com/ethereum/go-ethereum/crypto"
)

func TestMT(t *testing.T) {
	proofs := make([]common.Hash, 0)
	proofs = append(proofs, crypto.Keccak256Hash(common.HexToHash("0x1").Bytes()))
	proofs = append(proofs, crypto.Keccak256Hash(common.HexToHash("0x2").Bytes()))
	proofs = append(proofs, crypto.Keccak256Hash(common.HexToHash("0x3").Bytes()))
	proofs = append(proofs, crypto.Keccak256Hash(common.HexToHash("0x4").Bytes()))
	proofs = append(proofs, crypto.Keccak256Hash(common.HexToHash("0x5").Bytes()))
	proofs = append(proofs, crypto.Keccak256Hash(common.HexToHash("0x6").Bytes()))

	address := common.HexToAddress("0x1f9090aaE28b8a3dCeaDf281B0F12828e676c326")
	amount := big.NewInt(0).SetUint64(10)
	payload := append(address.Bytes(), common.LeftPadBytes(amount.Bytes(), 32)...)
	data := crypto.Keccak256Hash(payload)
	proofs = append(proofs, data)

	tree, err := NewMerkleTree(proofs)
	if err != nil {
		t.Fatal(err)
	}

	mproofs, err := tree.GetProof(data)
	if err != nil {
		t.Fatal(err)
	}

	t.Log(tree.GetRoot().Hex())

	for _, el := range mproofs {
		t.Log(hex.EncodeToString(el[:]))
	}

}
